"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.lintBinCommand = void 0;
var tslib_1 = require("tslib");
var fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
var path_1 = tslib_1.__importDefault(require("path"));
var eslint_1 = require("eslint");
var utils_1 = require("../../shared/utils");
var lint_config_1 = require("../../configs/lint.config");
var messages_1 = require("../../shared/messages");
var package_const_1 = require("../../shared/constants/package.const");
exports.lintBinCommand = function (prog) {
    prog
        .command('lint')
        .describe('Lint a package. (default lint pattern src/**/*.{js,jsx,ts,tsx}')
        // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
        // @ts-ignore
        .alias('l')
        .option('fix', 'Resolve fixable eslint errors')
        .example('lint --fix')
        .option('ignore-pattern', 'Ignore a pattern')
        .example('lint --ignore-pattern src/foo.ts')
        .action(function (opts) { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var time, files, project, dir, isRoot, _a, hasPackageDir, rootDir, _b, packageJsonPath, eslintConfig, lintConfig, cli, report, duration;
        return tslib_1.__generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    time = process.hrtime();
                    files = opts._.length > 0 ? opts._ : ['src/**/*.{js,jsx,ts,tsx}'];
                    project = [];
                    dir = '';
                    isRoot = false;
                    _c.label = 1;
                case 1:
                    _c.trys.push([1, 3, , 4]);
                    return [4 /*yield*/, utils_1.findWorkspacePackageDir(true)];
                case 2:
                    dir = _c.sent();
                    project.push(path_1.default.resolve(dir, package_const_1.TSCONFIG_JSON));
                    return [3 /*break*/, 4];
                case 3:
                    _a = _c.sent();
                    return [3 /*break*/, 4];
                case 4:
                    _c.trys.push([4, 6, , 7]);
                    hasPackageDir = dir !== '';
                    return [4 /*yield*/, utils_1.findWorkspaceRootDir(hasPackageDir)];
                case 5:
                    rootDir = _c.sent();
                    isRoot = true;
                    if (!hasPackageDir) {
                        dir = rootDir;
                    }
                    project.push(path_1.default.resolve(rootDir, package_const_1.TSCONFIG_JSON));
                    return [3 /*break*/, 7];
                case 6:
                    _b = _c.sent();
                    return [3 /*break*/, 7];
                case 7:
                    packageJsonPath = path_1.default.resolve(dir, package_const_1.PACKAGE_JSON);
                    return [4 /*yield*/, fs_extra_1.default.readJSON(packageJsonPath)];
                case 8:
                    eslintConfig = (_c.sent()).eslintConfig;
                    lintConfig = lint_config_1.createLintConfig({ dir: dir, isRoot: isRoot });
                    cli = new eslint_1.CLIEngine({
                        baseConfig: tslib_1.__assign(tslib_1.__assign({}, lintConfig), (eslintConfig || {})),
                        extensions: ['.ts', '.tsx', '.js', '.jsx'],
                        fix: opts.fix,
                        ignorePattern: opts['ignore-pattern'],
                        parser: '@typescript-eslint/parser',
                        parserOptions: {
                            tsconfigRootDir: dir,
                            project: project
                        }
                    });
                    console.log(messages_1.lintMessage.linting(files));
                    report = cli.executeOnFiles(files);
                    if (opts.fix) {
                        eslint_1.CLIEngine.outputFixes(report);
                    }
                    console.log(cli.getFormatter()(report.results));
                    duration = process.hrtime(time);
                    console.log(messages_1.lintMessage.linted(duration));
                    if (report.errorCount) {
                        process.exit(1);
                    }
                    return [2 /*return*/];
            }
        });
    }); });
};
